@@ -1,4 +1,7 @@
 package YATG::Callback;
+{
+  $YATG::Callback::VERSION = '4.112530';
+}
 
 use strict;
 use warnings FATAL => 'all';
@@ -79,12 +82,3 @@ sub snmp_callback {
 }
 
 1;
-
-
-__END__
-
-Copyright (c) The University of Oxford 2007.
-
-This library is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
-
