@@ -1,4 +1,7 @@
 package YATG::Retrieve::RPC;
+{
+  $YATG::Retrieve::RPC::VERSION = '4.112530';
+}
 
 use strict;
 use warnings FATAL => 'all';
@@ -26,13 +29,20 @@ sub retrieve {
 
 1;
 
+# ABSTRACT: Retrieve a set of polled data over the network
+
 
 __END__
+=pod
 
 =head1 NAME
 
 YATG::Retrieve::RPC - Retrieve a set of polled data over the network
 
+=head1 VERSION
+
+version 4.112530
+
 =head1 DESCRIPTION
 
 You can load this module to retrieve a set of data which has previously been
@@ -76,13 +86,14 @@ instance the default serializer is set to L<YAML::Syck> so to change that try:
 
 =head1 AUTHOR
 
-Oliver Gorwits C<< <oliver.gorwits@oucs.ox.ac.uk> >>
+Oliver Gorwits <oliver@cpan.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (c) The University of Oxford 2007.
+This software is copyright (c) 2011 by University of Oxford.
 
-This library is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
