@@ -1,4 +1,7 @@
 package YATG::SharedStorage;
+{
+  $YATG::SharedStorage::VERSION = '4.112530';
+}
 
 use strict;
 use warnings FATAL => 'all';
@@ -14,12 +17,3 @@ sub factory {
 }
 
 1;
-
-
-__END__
-
-Copyright (c) The University of Oxford 2007.
-
-This library is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
-
