@@ -1,4 +1,7 @@
 package YATG::Store::Disk;
+{
+  $YATG::Store::Disk::VERSION = '4.112530';
+}
 
 use strict;
 use warnings FATAL => 'all';
@@ -69,12 +72,20 @@ sub store {
 
 1;
 
+# ABSTRACT: Back-end module to store polled data to disk
+
+
 __END__
+=pod
 
 =head1 NAME
 
 YATG::Store::Disk - Back-end module to store polled data to disk
 
+=head1 VERSION
+
+version 4.112530
+
 =head1 DESCRIPTION
 
 This module implements part of a callback handler used to store SNMP data to
@@ -135,13 +146,14 @@ to create files and directories and write to them in this location.
 
 =head1 AUTHOR
 
-Oliver Gorwits C<< <oliver.gorwits@oucs.ox.ac.uk> >>
+Oliver Gorwits <oliver@cpan.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (c) The University of Oxford 2007.
+This software is copyright (c) 2011 by University of Oxford.
 
-This library is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
